# Copyright (c) 2021 Secureworks. All Rights Reserved
# Configure the Azure AD Provider

terraform {
  required_providers {
    azuread = {
      source  = "hashicorp/azuread"
      version = "=2.31.0"
    }
    azurerm = {
      source  = "hashicorp/azurerm"
      version = "=3.38.0"
    }
  }
}

provider "azuread" {
  tenant_id = var.azure_tenant_id
}

# Configure the Azure Provider
provider "azurerm" {
  tenant_id       = var.azure_tenant_id
  subscription_id = var.azure_subscription_id

  features {}
}

# Azure configurations
variable "client_name" {
  type        = string
  description = "Your organization's name"
  default     = "YourOrg"
}
variable "azure_tenant_id" {
  type        = string
  description = "Azure tenant ID"
  default     = "00000000-0000-0000-0000-000000000000"
}

variable "azure_subscription_id" {
  type        = string
  description = "Azure subscription ID"
  default     = "00000000-0000-0000-0000-000000000000"
}

variable "azure_region" {
  type        = string
  description = "Region of the azure resource"
  default     = "eastus"
}

variable "resource_group_name" {
  type        = string
  description = "Resource group name"
  default     = "scwx-datp-integration-rg"
}

variable "require_dedicated_cluster" {
  description = "Whether the corresponding workspace needs a dedicated event hub cluster"
  default     = false
  type        = bool
}

variable "eventhub_tier" {
  type        = string
  description = "The tier to use with the eventhub namespace. Allowed values are Standard and Premium"
  validation {
    condition     = contains(["Standard", "Premium"], var.eventhub_tier)
    error_message = "The value of eventhub_tier must be one of: \"Standard\", \"Premium\"."
  }
}

variable "eventhub_throughput_allocated" {
  type        = number
  description = "The number of throughput units allocated at the creation time of Standard-tier eventhub namespace. Allowed values are between 1 and 32"
  default     = 2
  validation {
    condition     = var.eventhub_throughput_allocated >= 1 && var.eventhub_throughput_allocated <= 32
    error_message = "The value of eventhub_throughput_allocated must be between 1 and 32."
  }
}

variable "eventhub_throughput_inflate_cap" {
  type        = number
  description = "The maximum number of throughput units that can be allocated to Standard-tier eventhub namespace through Auto-inflate. Allowed values are between 1 and 32"
  default     = 4
  validation {
    condition     = var.eventhub_throughput_inflate_cap >= 1 && var.eventhub_throughput_inflate_cap <= 32
    error_message = "The value of eventhub_throughput_inflate_cap must be between 1 and 32."
  }
}

variable "eventhub_processing_units" {
  type        = number
  description = "The number of processing units allocated to Premium-tier eventhub namespace. Allowed values are between 1 and 16"
  default     = 1
  validation {
    condition     = var.eventhub_processing_units >= 1 && var.eventhub_processing_units <= 16
    error_message = "The value of eventhub_capacity_units must be between 1 and 16."
  }
}

variable "eventhub_partition_count" {
  type        = number
  description = "The number of partitions of the event hub. This should be equal to the number of throughput units the event hub will consume. Allowed values are between 1 and 32 for event hubs on a shared eventhub cluster, and between 1 and 1024 for event hubs on a dedicated eventhub cluster"
  default     = 4
  validation {
    condition     = var.eventhub_partition_count >= 1 && var.eventhub_partition_count <= 1024
    error_message = "The value of eventhub_partition_count must be between 1 and 1024."
  }
}

variable "data_retention_length" {
  type        = number
  description = "The number of days data is retained in the event hub. Minimum value 1 (day). If using dedicated event hub cluster, maximum value will be 90 (days). If using shared event hub cluster with Standard tier SKU, maximum value is 7"
  default     = 1
  validation {
    condition     = var.data_retention_length >= 1 && var.data_retention_length <= 90
    error_message = "The value of data_retention_length must be between 1 and 90."
  }
}

variable "azure_resource_tags" {
  type        = map(any)
  description = "Map of tags that will be applied to all resources created"
  default     = {}
}

variable "eventhub_zone_redundancy_regions" {
  type        = list
  description = "List of azure regions that supports zone redundancy"
  default = ["brazilsouth", "canadacentral", "centralus", "eastus", "eastus2", "southcentralus", "westus2", "francecentral", "germanywestcentral",  "northeurope", "uksouth", "westeurope", "australiaeast", "japaneast", "southeastasia"]
}

variable "replacement_eventhub" {
  type = bool
  description = "Is this a replacement eventhub?"
  default = false
}
